==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core-utils/lumina-search/i18n/lumina-search_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>ConfigUI</name>
    <message>
        <location filename="../ConfigUI.ui" line="14"/>
        <source>Search Configuration</source>
        <translation>Διαμόρφωση αναζήτησης</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="20"/>
        <source>Start Search:</source>
        <translation>Έναρξη αναζήτησης</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="39"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="48"/>
        <source>Excluded Directories</source>
        <translation>Κατάλογοι που εξαιρούνται</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="119"/>
        <source>Save as Defaults</source>
        <translation>Αποθήκευση ως προκαθορισμένα</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="41"/>
        <source>Select Search Directory</source>
        <translation>Επιλογή Καταλόγου Αναζήτησης</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="54"/>
        <source>Exclude Directories</source>
        <translation>Εξαίρεση Καταλόγων</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Search For...</source>
        <translation>Αναζήτηση για...</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="23"/>
        <source>Type to search</source>
        <translation>Πληκτρολογήστε για αναζήτηση</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="30"/>
        <source>Configure search parameters</source>
        <translation>Ρύθμιση παραμέτρων αναζήτησης</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="40"/>
        <source>Stop Active Search</source>
        <translation>Τερματισμός τρέχουσας αναζήτησης</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="54"/>
        <source>Applications</source>
        <translation>Εφαρμογές</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="64"/>
        <source>Files or Directories</source>
        <translation>Αρχεία ή κατάλογοι</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="88"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Launch Item</source>
        <translation>Εκτέλεση στοιχείου</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="119"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="122"/>
        <location filename="../MainUI.ui" line="125"/>
        <source>Save Screenshot</source>
        <translation>Αποθήκευση στιγμιότυπου οθόνης</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="136"/>
        <source>Quit</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="141"/>
        <source>Snap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="144"/>
        <source>Take new snapshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="29"/>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="95"/>
        <source>Search: %1 -- Smart: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="98"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="98"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Worker</name>
    <message>
        <location filename="../Worker.cpp" line="42"/>
        <source>Searching: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="63"/>
        <source>Starting Search: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="111"/>
        <source>Search Finished</source>
        <translation>Η αναζήτηση ολοκληρώθηκε</translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/core-utils/lumina-search/i18n/lumina-search_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>ConfigUI</name>
    <message>
        <location filename="../ConfigUI.ui" line="14"/>
        <source>Search Configuration</source>
        <translation>Διαμόρφωση αναζήτησης</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="20"/>
        <source>Start Search:</source>
        <translation>Έναρξη αναζήτησης</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="39"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="48"/>
        <source>Excluded Directories</source>
        <translation>Κατάλογοι που εξαιρούνται</translation>
    </message>
    <message>
        <location filename="../ConfigUI.ui" line="119"/>
        <source>Save as Defaults</source>
        <translation>Αποθήκευση ως προκαθορισμένα</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="41"/>
        <source>Select Search Directory</source>
        <translation>Επιλογή Καταλόγου Αναζήτησης</translation>
    </message>
    <message>
        <location filename="../ConfigUI.cpp" line="54"/>
        <source>Exclude Directories</source>
        <translation>Εξαίρεση Καταλόγων</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Search For...</source>
        <translation>Αναζήτηση για...</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="23"/>
        <source>Type to search</source>
        <translation>Πληκτρολογήστε για αναζήτηση</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="30"/>
        <source>Configure search parameters</source>
        <translation>Ρύθμιση παραμέτρων αναζήτησης</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="40"/>
        <source>Stop Active Search</source>
        <translation>Τερματισμός τρέχουσας αναζήτησης</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="54"/>
        <source>Applications</source>
        <translation>Εφαρμογές</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="64"/>
        <source>Files or Directories</source>
        <translation>Αρχεία ή κατάλογοι</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="88"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Launch Item</source>
        <translation>Εκτέλεση στοιχείου</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="119"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="122"/>
        <location filename="../MainUI.ui" line="125"/>
        <source>Save Screenshot</source>
        <translation>Αποθήκευση στιγμιότυπου οθόνης</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="136"/>
        <source>Quit</source>
        <translation>Τερματισμός</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="141"/>
        <source>Snap</source>
        <translation>Στιγμιότυπο</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="144"/>
        <source>Take new snapshot</source>
        <translation>Πάρτε νέο στιγμιότυπο</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="29"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="96"/>
        <source>Search: %1 -- Smart: %2</source>
        <translation type="unfinished">Αναζήτηση: % 1 - Smart: % 2</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="99"/>
        <source>Off</source>
        <translation>Κλειστό</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="99"/>
        <source>On</source>
        <translation>Ανοιχτό</translation>
    </message>
</context>
<context>
    <name>Worker</name>
    <message>
        <location filename="../Worker.cpp" line="42"/>
        <source>Searching: %1</source>
        <translation>Αναζήτηση: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="64"/>
        <source>Starting Search: %1</source>
        <translation>Ξεκινώντας την αναζήτηση: %1</translation>
    </message>
    <message>
        <location filename="../Worker.cpp" line="112"/>
        <source>Search Finished</source>
        <translation>Η αναζήτηση ολοκληρώθηκε</translation>
    </message>
</context>
</TS>
